@@ -235,8 +235,8 @@ void TagLibExtractorTest::testVorbisCommentMultivalue()
     SimpleExtractionResult result(testFilePath(fileName), mimeType);
     plugin.extract(&result);
 
-    QCOMPARE(result.properties().values(Property::Artist), QVariantList({QStringLiteral("Artist1"), QStringLiteral("Artist2")}));
-    QCOMPARE(result.properties().values(Property::Genre), QVariantList({QStringLiteral("Genre1"), QStringLiteral("Genre2")}));
+    QCOMPARE(result.properties(KFileMetaData::MultiMap).values(Property::Artist), QVariantList({QStringLiteral("Artist1"), QStringLiteral("Artist2")}));
+    QCOMPARE(result.properties(KFileMetaData::MultiMap).values(Property::Genre), QVariantList({QStringLiteral("Genre1"), QStringLiteral("Genre2")}));
 }
 
 void TagLibExtractorTest::testVorbisCommentMultivalue_data()
@@ -430,9 +430,8 @@ void TagLibExtractorTest::testAsf_data()
 {
     QTest::addColumn<QString>("fileType");
 
-    QTest::addRow("asf")
-        << QStringLiteral("wma")
-        ;
+    // ASF container format, used by WMA
+    QTest::addRow("wma") << QStringLiteral("wma");
 }
 
 void TagLibExtractorTest::testId3Rating_data()
@@ -611,16 +610,11 @@ void  TagLibExtractorTest::testNoMetadata()
     SimpleExtractionResult extracted(path, mimeType);
     plugin.extract(&extracted);
 
-    const auto resultList = extracted.properties();
+    const auto resultList = extracted.properties(KFileMetaData::MultiMap);
     const auto resultKeys = resultList.uniqueKeys();
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    const QSet<KFileMetaData::Property::Property> resultKeySet = resultKeys.toSet();
-    const QSet<KFileMetaData::Property::Property> expectedKeySet = expectedKeys.toSet();
-#else
     const QSet<KFileMetaData::Property::Property> resultKeySet(resultKeys.begin(), resultKeys.end());
     const QSet<KFileMetaData::Property::Property> expectedKeySet(expectedKeys.begin(), expectedKeys.end());
-#endif
 
     const auto excessKeys = resultKeySet - expectedKeySet;
     const auto missingKeys = expectedKeySet - resultKeySet;
@@ -655,7 +649,7 @@ void TagLibExtractorTest::testRobustness_data()
 
     QTest::addRow("ArcGIS GeoData spx")
             << QFINDTESTDATA("samplefiles/misdetected/test_arcgis_geodata.spx")
-            << QStringLiteral("audio/speex");
+            << QStringLiteral("audio/x-speex+ogg");
 }
 
 void TagLibExtractorTest::testRobustness()
